@@ -3,17 +3,23 @@ import os
 import threading
 import logging
 import time
+from datetime import datetime
 from functools import partial
+from pathlib import Path
+from typing import Union, List, Dict
 
+import boxsdk.object.file
+import dateutil
 import pyinotify
 from boxsdk import Client
 from boxsdk.exception import BoxAPIException
 from boxsdk.object.file import File
 from boxsdk.object.folder import Folder
-from requests import ConnectionError
+from dateutil import tz
+from requests.exceptions import ConnectionError
 from urllib3.exceptions import ProtocolError
 
-from .cache_utils import redis_key, redis_get, r_c
+from .cache_utils import redis_key, redis_get, r_c, local_or_box_file_m_time_key_func
 from .iter_utils import SafeIter
 from .log_utils import setup_logger
 
@@ -21,17 +27,17 @@ setup_logger()
 
 crate_logger = logging.getLogger(__name__)
 
-trash_directory = os.path.expanduser("~/.local/share/Trash/files")
+trash_directory = Path("~/.local/share/Trash/files").expanduser().resolve()
 
 conf_obj = configparser.ConfigParser()
-conf_dir = os.path.abspath(os.path.expanduser("~/.config/diycrate"))
-if not os.path.isdir(conf_dir):
-    os.mkdir(conf_dir)
-cloud_credentials_file_path = os.path.join(conf_dir, "box.ini")
-if not os.path.isfile(cloud_credentials_file_path):
-    open(cloud_credentials_file_path, "w").write("")
+conf_dir = Path("~/.config/diycrate").expanduser().resolve()
+if not conf_dir.is_dir():
+    conf_dir.mkdir()
+cloud_credentials_file_path = conf_dir / "box.ini"
+if not cloud_credentials_file_path.is_file():
+    cloud_credentials_file_path.write_text("")
 conf_obj.read(cloud_credentials_file_path)
-BOX_DIR = os.path.expanduser(conf_obj["box"]["directory"])
+BOX_DIR = Path(conf_obj["box"]["directory"]).expanduser().resolve()
 
 
 class EventHandler(pyinotify.ProcessEvent):
@@ -44,7 +50,7 @@ class EventHandler(pyinotify.ProcessEvent):
         Extends the super to add cloud storage state.
         :return:
         """
-        our_keys = ["oauth", "upload_queue", "bottle_app", "oauth_meta_info"]
+        our_keys = ["oauth", "upload_queue", "bottle_app"]
         our_kargs = {k: kargs.get(k) for k in our_keys}
         for key in our_keys:
             kargs.pop(key, None)
@@ -59,7 +65,6 @@ class EventHandler(pyinotify.ProcessEvent):
         self.oauth = kargs.get("oauth")
         self.operations_thread = threading.Thread(target=self.operation_coalesce)
         self.bottle_app = kargs.get("bottle_app")
-        self.oauth_meta_info = kargs.get("oauth_meta_info")
         self.operations_thread.daemon = True
         self.operations_thread.start()
 
@@ -88,7 +93,7 @@ class EventHandler(pyinotify.ProcessEvent):
                     self.process_event(*operation)
 
     @staticmethod
-    def get_folder(client, folder_id):
+    def get_folder(client, folder_id: str) -> Folder:
         """
 
         :param client:
@@ -120,19 +125,19 @@ class EventHandler(pyinotify.ProcessEvent):
         return folder
 
     @staticmethod
-    def folders_to_traverse(event_path):
+    def folders_to_traverse(event_path: Union[str, Path]) -> List[str]:
         """
 
         :param event_path:
         :return:
         """
+        if isinstance(event_path, str):
+            event_path = Path(event_path)
         folders_to_traverse = [
             folder
-            for folder in event_path.replace(BOX_DIR, "").split(os.path.sep)
+            for folder in event_path.relative_to(BOX_DIR).parts
             if folder and folder != "/"
         ]
-        if len(folders_to_traverse) and folders_to_traverse[0][0] == "/":
-            folders_to_traverse[0] = folders_to_traverse[0][1:]
         return folders_to_traverse
 
     @staticmethod
@@ -158,7 +163,7 @@ class EventHandler(pyinotify.ProcessEvent):
                         if folder == entry["name"] and entry["type"] == "folder":
                             did_find_folder = True
                             cur_box_folder = EventHandler.get_folder(
-                                client, entry["id"]
+                                client, entry.object_id
                             )
                             break  # found this piece of the path, keep going
                 except BoxAPIException:
@@ -205,31 +210,35 @@ class EventHandler(pyinotify.ProcessEvent):
             )
 
     def process_real_close_event(self, event):
-        crate_logger.debug("Real  close...: {}".format(event.pathname))
-        folders_to_traverse = self.folders_to_traverse(event.path)
+        file_path = Path(event.pathname)
+        crate_logger.debug("Real  close...: {}".format(file_path.as_posix()))
+        folders_to_traverse = self.folders_to_traverse(file_path.parent.as_posix())
         crate_logger.debug(folders_to_traverse)
         client = Client(self.oauth)
         cur_box_folder = None
         cur_box_folder = get_box_folder(client, cur_box_folder, "0", 5)
         # if we're modifying in root box dir, then we've already found the folder
-        is_base = BOX_DIR in (event.path, event.path[:-1])
+        try:
+            is_base = any(
+                Path(evp).relative_to(BOX_DIR) for evp in [event.path, event.path[:-1]]
+            )
+        except ValueError:
+            is_base = False
         cur_box_folder = self.traverse_path(
             client, event, cur_box_folder, folders_to_traverse
         )
-        last_dir = os.path.split(event.path)[-1]
+        last_dir = Path(event.path).parent.name
         if not is_base:
             AssertionError(
                 cur_box_folder["name"] == last_dir,
                 cur_box_folder["name"] + "not equals " + last_dir,
             )
-        did_find_the_file = os.path.isdir(
-            event.pathname
-        )  # true if we are a directory :)
+        did_find_the_file = os.path.isdir(file_path)  # true if we are a directory :)
         did_find_the_folder = os.path.isfile(
-            event.pathname
+            file_path
         )  # true if we are a regular file :)
-        is_file = os.path.isfile(event.pathname)
-        is_dir = os.path.isdir(event.pathname)
+        is_file = file_path.is_file()
+        is_dir = file_path.is_dir()
         limit = 100
         offset = 0
         safe_iter = SafeIter(
@@ -239,33 +248,53 @@ class EventHandler(pyinotify.ProcessEvent):
             if entry is None:
                 continue
             did_find_the_file = (
-                is_file and entry["type"] == "file" and entry["name"] == event.name
+                is_file and entry["type"] == "file" and entry["name"] == file_path.name
             )
             did_find_the_folder = (
-                is_dir and entry["type"] == "folder" and entry["name"] == event.name
+                is_dir and entry["type"] == "folder" and entry["name"] == file_path.name
             )
             if did_find_the_file:
                 break
         # not a box file/folder (though could have been copied from a local box item)
         if is_file and not did_find_the_file:
-            last_modified_time = os.path.getmtime(event.pathname)
+            last_modified_time = (
+                datetime.fromtimestamp(file_path.stat().st_mtime)
+                .astimezone(dateutil.tz.tzutc())
+                .timestamp()
+            )
             self.upload_queue.put(
                 [
                     last_modified_time,
-                    partial(cur_box_folder.upload, event.pathname, event.name),
+                    partial(
+                        cur_box_folder.upload, file_path.as_posix(), file_path.name
+                    ),
                     self.oauth,
                 ]
             )
         elif is_dir and not did_find_the_folder:
-            cur_box_folder.create_subfolder(event.name)
-            wm.add_watch(event.pathname, rec=True, mask=mask, auto_add=True)
+            cur_box_folder.create_subfolder(file_path.name)
+            wm.add_watch(file_path.as_posix(), rec=True, mask=mask, auto_add=True)
             # TODO: recursively add this directory to box
 
     def process_modify_event(self, event, operation):
+        file_path = Path(event.pathname)
+        if file_path.name.startswith(".goutputstream"):
+            return
+        # if file_path.name.endswith(".tmp"):
+        #     return
         crate_logger.debug(
-            "{op}...: {pathname}".format(op=operation, pathname=event.pathname)
+            "{op}...: {pathname}".format(op=operation, pathname=file_path.as_posix())
         )
-        folders_to_traverse = self.folders_to_traverse(event.path)
+        try:
+            r_c.set(
+                local_or_box_file_m_time_key_func(file_path.as_posix(), False),
+                datetime.fromtimestamp(file_path.stat().st_mtime)
+                .astimezone(dateutil.tz.tzutc())
+                .timestamp(),
+            )
+        except FileNotFoundError:
+            pass
+        folders_to_traverse = self.folders_to_traverse(file_path.parent.as_posix())
         crate_logger.debug(folders_to_traverse)
         client = Client(self.oauth)
         cur_box_folder = None
@@ -273,39 +302,43 @@ class EventHandler(pyinotify.ProcessEvent):
         retry_limit = 5
         cur_box_folder = get_box_folder(client, cur_box_folder, folder_id, retry_limit)
         # if we're modifying in root box dir, then we've already found the folder
-        is_base = BOX_DIR in (event.path, event.path[:-1])
+        try:
+            is_base = any(
+                Path(evp).relative_to(BOX_DIR) for evp in [event.path, event.path[:-1]]
+            )
+        except ValueError:
+            is_base = False
         cur_box_folder = self.traverse_path(
             client, event, cur_box_folder, folders_to_traverse
         )
-        last_dir = os.path.split(event.path)[-1]
+        last_dir = Path(event.path).parent.name
         if not is_base:
             AssertionError(
                 cur_box_folder["name"] == last_dir,
                 cur_box_folder["name"] + "not equals " + last_dir,
             )
-        did_find_the_file = os.path.isdir(
-            event.pathname
-        )  # true if we are a directory :)
+        did_find_the_file = os.path.isdir(file_path)  # true if we are a directory :)
         did_find_the_folder = os.path.isfile(
-            event.pathname
+            file_path
         )  # true if we are a regular file :)
-        is_file = os.path.isfile(event.pathname)
-        is_dir = os.path.isdir(event.pathname)
+        is_file = os.path.isfile(file_path)
+        is_dir = os.path.isdir(file_path)
         limit = 100
         offset = 0
+
         for entry in cur_box_folder.get_items(offset=offset, limit=limit):
             did_find_the_file = (
-                is_file and entry["type"] == "file" and entry["name"] == event.name
+                is_file and entry["type"] == "file" and entry["name"] == file_path.name
             )
             did_find_the_folder = (
-                is_dir and entry["type"] == "folder" and entry["name"] == event.name
+                is_dir and entry["type"] == "folder" and entry["name"] == file_path.name
             )
             if did_find_the_file:
-                last_modified_time = os.path.getmtime(event.pathname)
-                if entry["id"] not in self.files_from_box:
-                    cur_file = client.file(file_id=entry["id"]).get()
+                last_modified_time = file_path.stat().st_mtime
+                if entry.object_id not in self.files_from_box:
+                    cur_file = client.file(file_id=entry.object_id).get()
                     can_update = True
-                    was_versioned = r_c.exists(redis_key(cur_file["id"]))
+                    was_versioned = r_c.exists(redis_key(cur_file.object_id))
                     try:
                         info = redis_get(r_c, cur_file) if was_versioned else None
                         info = (
@@ -328,8 +361,12 @@ class EventHandler(pyinotify.ProcessEvent):
                         if can_update:
                             self.upload_queue.put(
                                 [
-                                    last_modified_time,
-                                    partial(cur_file.update_contents, event.pathname),
+                                    datetime.fromtimestamp(last_modified_time)
+                                    .astimezone(dateutil.tz.tzutc())
+                                    .timestamp(),
+                                    partial(
+                                        cur_file.update_contents, file_path.as_posix()
+                                    ),
                                     self.oauth,
                                 ]
                             )
@@ -349,7 +386,7 @@ class EventHandler(pyinotify.ProcessEvent):
                                     fresh_download=item_version["fresh_download"],
                                     new_time_stamp=is_new_time_stamp,
                                     path_name=event.pathname,
-                                    obj_id=cur_file["id"],
+                                    obj_id=cur_file.object_id,
                                 )
                             )
                     except TypeError:
@@ -359,11 +396,11 @@ class EventHandler(pyinotify.ProcessEvent):
 
                 else:
                     self.files_from_box.remove(
-                        entry["id"]
+                        entry.object_id
                     )  # just wrote if, assuming create event didn't run
                 break
             elif did_find_the_folder:
-                if entry["id"] not in self.folders_from_box:
+                if entry.object_id not in self.folders_from_box:
                     crate_logger.debug(
                         "Cannot create a subfolder when it already exists: {}".format(
                             event.pathname
@@ -373,23 +410,31 @@ class EventHandler(pyinotify.ProcessEvent):
                     # upload_queue.put(partial(cur_folder.update_contents, event.pathname))
                 else:
                     self.folders_from_box.remove(
-                        entry["id"]
+                        entry.object_id
                     )  # just wrote if, assuming create event didn't run
                 break
         if is_file and not did_find_the_file:
-            crate_logger.debug("Uploading contents...: {}".format(event.pathname))
-            last_modified_time = os.path.getmtime(event.pathname)
+            crate_logger.debug("Uploading contents...: {}".format(file_path.as_posix()))
+            last_modified_time = Path(event.pathname).stat().st_mtime
             self.upload_queue.put(
                 [
-                    last_modified_time,
-                    partial(cur_box_folder.upload, event.pathname, event.name),
+                    datetime.fromtimestamp(last_modified_time)
+                    .astimezone(dateutil.tz.tzutc())
+                    .timestamp(),
+                    partial(
+                        cur_box_folder.upload, file_path.as_posix(), file_path.name
+                    ),
                     self.oauth,
                 ]
             )
         if is_dir and not did_find_the_folder:
-            crate_logger.debug("Creating a sub-folder...: {}".format(event.pathname))
-            self.upload_queue.put(partial(cur_box_folder.create_subfolder, event.name))
-            wm.add_watch(event.pathname, rec=True, mask=mask)
+            crate_logger.debug(
+                "Creating a sub-folder...: {}".format(file_path.as_posix())
+            )
+            self.upload_queue.put(
+                partial(cur_box_folder.create_subfolder, file_path.name)
+            )
+            wm.add_watch(file_path.as_posix(), rec=True, mask=mask)
 
     def process_create_event(self, event):
         crate_logger.debug("Creating: {}".format(event.pathname))
@@ -408,11 +453,16 @@ class EventHandler(pyinotify.ProcessEvent):
                 failed = True
         cur_box_folder = box_folder
         # if we're modifying in root box dir, then we've already found the folder
-        is_base = BOX_DIR in (event.path, event.path[:-1])
+        try:
+            is_base = any(
+                Path(evp).relative_to(BOX_DIR) for evp in [event.path, event.path[:-1]]
+            )
+        except ValueError:
+            is_base = False
         cur_box_folder = self.traverse_path(
             client, event, cur_box_folder, folders_to_traverse
         )
-        last_dir = os.path.split(event.path)[-1]
+        last_dir = Path(event.path).parent.name
         if not is_base:
             assert cur_box_folder["name"] == last_dir
         did_find_the_file = os.path.isdir(
@@ -427,10 +477,14 @@ class EventHandler(pyinotify.ProcessEvent):
         offset = 0
         for entry in cur_box_folder.get_items(offset=offset, limit=limit):
             did_find_the_file = (
-                is_file and entry["type"] == "file" and entry["name"] == event.name
+                is_file
+                and entry["type"] == "file"
+                and entry["name"] == os.path.basename(event.pathname)
             )
             did_find_the_folder = (
-                is_dir and entry["type"] == "folder" and entry["name"] == event.name
+                is_dir
+                and entry["type"] == "folder"
+                and entry["name"] == os.path.basename(event.pathname)
             )
             if did_find_the_file:
                 dwld_key = "diy_crate.breadcrumb.create_from_box.{path}".format(
@@ -438,9 +492,9 @@ class EventHandler(pyinotify.ProcessEvent):
                 )
                 file_created_from_download = r_c.exists(dwld_key)
                 if file_created_from_download:
-                    self.files_from_box.append(entry["id"])
+                    self.files_from_box.append(entry.object_id)
                     r_c.delete(dwld_key)
-                if entry["id"] not in self.files_from_box:
+                if entry.object_id not in self.files_from_box:
                     # more accurately, was this created offline?
                     AssertionError(
                         False,
@@ -476,14 +530,24 @@ class EventHandler(pyinotify.ProcessEvent):
             last_modified_time = os.path.getctime(event.pathname)
             self.upload_queue.put(
                 [
-                    last_modified_time,
-                    partial(cur_box_folder.upload, event.pathname, event.name),
+                    datetime.fromtimestamp(last_modified_time)
+                    .astimezone(dateutil.tz.tzutc())
+                    .timestamp(),
+                    partial(
+                        cur_box_folder.upload,
+                        event.pathname,
+                        os.path.basename(event.pathname),
+                    ),
                     self.oauth,
                 ]
             )
         elif is_dir and not did_find_the_folder:
             crate_logger.debug("Upload the folder: {}".format(event.pathname))
-            self.upload_queue.put(partial(cur_box_folder.create_subfolder, event.name))
+            self.upload_queue.put(
+                partial(
+                    cur_box_folder.create_subfolder, os.path.basename(event.pathname)
+                )
+            )
             wm.add_watch(event.pathname, rec=True, mask=mask)
 
     def process_move_event(self, event):
@@ -548,7 +612,9 @@ class EventHandler(pyinotify.ProcessEvent):
                     for cur_entry in cur_box_folder.get_items(
                         offset=cur_offset, limit=limit
                     ):
-                        matching_name = cur_entry["name"] == dest_event.name
+                        matching_name = cur_entry["name"] == os.path.basename(
+                            dest_event.pathname
+                        )
                         did_find_cur_file = (
                             is_file and matching_name and isinstance(cur_entry, File)
                         )
@@ -558,7 +624,11 @@ class EventHandler(pyinotify.ProcessEvent):
                         if did_find_cur_file:
                             self.upload_queue.put(
                                 [
-                                    os.path.getmtime(dest_event.pathname),
+                                    datetime.fromtimestamp(
+                                        Path(dest_event.pathname).stat().st_mtime
+                                    )
+                                    .astimezone(dateutil.tz.tzutc())
+                                    .timestamp(),
                                     partial(
                                         cur_entry.update_contents, dest_event.pathname
                                     ),
@@ -588,7 +658,57 @@ class EventHandler(pyinotify.ProcessEvent):
                     # do not yet support moving and renaming in one go
                     assert src_folder["name"] == dest_event.name
             elif entry["name"] == dest_event.name:
-                move_from_remote = True
+                if (
+                    Path(src_event.path) == Path(dest_event.path)
+                    and Path(src_event.name).stem == dest_event.name
+                    and src_event.name != dest_event.name
+                ):
+                    crate_logger.info(
+                        f"Detected conceptual same directory temp file rename from "
+                        f"{src_event.name=} to {dest_event.name=}"
+                    )
+                    cur_offset = 0
+                    cur_entry: Union[boxsdk.object.file.File, boxsdk.object.file.Item]
+                    for cur_entry in cur_box_folder.get_items(
+                        offset=cur_offset, limit=limit
+                    ):
+                        matching_name = cur_entry["name"] == os.path.basename(
+                            dest_event.pathname
+                        )
+                        if matching_name:
+                            crate_logger.debug(f"{cur_entry=} {type(cur_entry)=}")
+
+                        did_find_cur_file = (
+                            is_file and matching_name and isinstance(cur_entry, File)
+                        )
+                        did_find_cur_folder = (
+                            is_dir and matching_name and isinstance(cur_entry, Folder)
+                        )
+                        if did_find_cur_file:
+                            self.upload_queue.put(
+                                [
+                                    datetime.fromtimestamp(
+                                        Path(dest_event.pathname).stat().st_mtime
+                                    )
+                                    .astimezone(dateutil.tz.tzutc())
+                                    .timestamp(),
+                                    partial(
+                                        cur_entry.update_contents, dest_event.pathname
+                                    ),
+                                    self.oauth,
+                                ]
+                            )
+                            break
+                        elif did_find_cur_folder:
+                            crate_logger.debug(
+                                "do not currently support moving a same name folder "
+                                "into parent with"
+                                "folder inside of the same name -- would may need "
+                                "to update the contents"
+                            )
+                            break
+                else:
+                    move_from_remote = True
         if (
             not move_from_remote
         ):  # if it was moved from a different folder on remote, could be false still
@@ -602,21 +722,26 @@ class EventHandler(pyinotify.ProcessEvent):
                 if is_file and not did_find_src_file:
                     # src file [should] no longer exist[s].
                     # this file did not originate in box, too.
-                    last_modified_time = os.path.getmtime(dest_event.pathname)
+                    last_modified_time = Path(dest_event.pathname).stat().st_mtime
                     self.upload_queue.put(
                         [
-                            last_modified_time,
+                            datetime.fromtimestamp(last_modified_time)
+                            .astimezone(dateutil.tz.tzutc())
+                            .timestamp(),
                             partial(
                                 cur_box_folder.upload,
                                 dest_event.pathname,
-                                dest_event.name,
+                                os.path.basename(dest_event.pathname),
                             ),
                             self.oauth,
                         ]
                     )
                 elif is_dir and not did_find_src_folder:
                     self.upload_queue.put(
-                        partial(cur_box_folder.create_subfolder, dest_event.name)
+                        partial(
+                            cur_box_folder.create_subfolder,
+                            os.path.basename(dest_event.pathname),
+                        )
                     )
                     wm.add_watch(dest_event.pathname, rec=True, mask=mask)
 
@@ -626,6 +751,7 @@ class EventHandler(pyinotify.ProcessEvent):
         crate_logger.debug(folders_to_traverse)
         client = Client(self.oauth)
         failed = False
+        box_folder = None
         while not failed:
             try:
                 box_folder = client.folder(folder_id="0").get()
@@ -636,11 +762,16 @@ class EventHandler(pyinotify.ProcessEvent):
                 failed = True
         cur_box_folder = box_folder
         # if we're modifying in root box dir, then we've already found the folder
-        is_base = BOX_DIR in (event.path, event.path[:-1])
+        try:
+            is_base = any(
+                Path(evp).relative_to(BOX_DIR) for evp in [event.path, event.path[:-1]]
+            )
+        except ValueError:
+            is_base = False
         cur_box_folder = self.traverse_path(
             client, event, cur_box_folder, folders_to_traverse
         )
-        last_dir = os.path.split(event.path)[-1]
+        last_dir = Path(event.path).parent.name
         if not is_base:
             AssertionError(
                 cur_box_folder["name"] == last_dir,
@@ -653,7 +784,7 @@ class EventHandler(pyinotify.ProcessEvent):
             if (
                 not event_was_for_dir
                 and entry["type"] == "file"
-                and entry["name"] == event.name
+                and entry["name"] == os.path.basename(event.pathname)
             ):
                 if entry["id"] not in self.files_from_box:
                     cur_file = client.file(file_id=entry["id"]).get()
@@ -670,7 +801,7 @@ class EventHandler(pyinotify.ProcessEvent):
             elif (
                 event_was_for_dir
                 and entry["type"] == "folder"
-                and entry["name"] == event.name
+                and entry["name"] == os.path.basename(event.pathname)
             ):
                 if entry["id"] not in self.folders_from_box:
                     self.get_folder(client, entry["id"]).delete()
@@ -688,7 +819,9 @@ class EventHandler(pyinotify.ProcessEvent):
         :param event:
         :return:
         """
-        if not event.name.startswith(".~lock"):  # avoid propagating lock files
+        if not os.path.basename(event.pathname).startswith(
+            ".~lock"
+        ):  # avoid propagating lock files
             self.operations.append([event, "create"])
 
     def process_IN_DELETE(self, event):
@@ -705,7 +838,9 @@ class EventHandler(pyinotify.ProcessEvent):
         :param event:
         :return:
         """
-        if not event.name.startswith(".~lock"):  # avoid propagating lock files
+        if not os.path.basename(event.pathname).startswith(
+            ".~lock"
+        ):  # avoid propagating lock files
             self.operations.append([event, "modify"])
 
     def process_IN_MOVED_FROM(self, event):
@@ -714,7 +849,9 @@ class EventHandler(pyinotify.ProcessEvent):
         :param event:
         :return:
         """
-        if not event.name.startswith(".~lock"):  # avoid propagating lock files
+        if not os.path.basename(event.pathname).startswith(
+            ".~lock"
+        ):  # avoid propagating lock files
             crate_logger.debug("Moved from: {}".format(event.pathname))
             self.move_events.append(event)
 
@@ -725,16 +862,14 @@ class EventHandler(pyinotify.ProcessEvent):
         :return:
         """
         found_from = False
-        to_trash = (
-            os.path.commonprefix([trash_directory, event.pathname]) == trash_directory
-        )
-        to_box = os.path.commonprefix([BOX_DIR, event.pathname]) == BOX_DIR
+        to_trash = trash_directory == Path(event.pathname).parent
+        to_box = BOX_DIR in Path(event.pathname).parents
         for move_event in self.move_events:
             was_moved_from = "in_moved_from" in move_event.maskname.lower()
             if (
                 move_event.cookie == event.cookie
                 and was_moved_from
-                and os.path.commonprefix([BOX_DIR, move_event.pathname]) == BOX_DIR
+                and BOX_DIR in Path(move_event.pathname).parents
             ):
                 found_from = True
                 # only count deletes that come from within the box path --
@@ -757,7 +892,9 @@ class EventHandler(pyinotify.ProcessEvent):
         :param event:
         :return:
         """
-        if not event.name.startswith(".~lock"):  # avoid propagating lock files
+        if not os.path.basename(event.pathname).startswith(
+            ".~lock"
+        ):  # avoid propagating lock files
             crate_logger.debug("Had a close on: {}".format(event))
             self.operations.append([event, "real_close"])
 
@@ -784,7 +921,7 @@ def get_box_folder(client, cur_box_folder, folder_id, retry_limit):
             BoxAPIException,
         ):
             if i + 1 >= retry_limit:
-                crate_logger.warn(
+                crate_logger.warning(
                     "Attempt ({retry_count}) out of ({max_count}); Going to give "
                     "up on the write event".format(
                         retry_count=i, max_count=retry_limit
@@ -792,7 +929,7 @@ def get_box_folder(client, cur_box_folder, folder_id, retry_limit):
                     exc_info=True,
                 )
             else:
-                crate_logger.warn(
+                crate_logger.warning(
                     "Attempt ({retry_count}) "
                     "out of ({max_count})".format(retry_count=i, max_count=retry_limit),
                     exc_info=True,
@@ -800,6 +937,31 @@ def get_box_folder(client, cur_box_folder, folder_id, retry_limit):
     return cur_box_folder
 
 
+def path_time_recurse_func(cur_path, wm=None) -> Dict[str, float]:
+    cur_data_map = {
+        Path(cur_path)
+        .resolve()
+        .as_posix(): datetime.fromtimestamp(os.path.getmtime(cur_path))
+        .astimezone(tz.UTC)
+        .timestamp()
+    }
+    cur_path = Path(cur_path)
+    for sub_cur_path in cur_path.iterdir():
+        if wm:
+            wm.add_watch(sub_cur_path.as_posix(), mask, rec=True, auto_add=True)
+        if sub_cur_path.is_file():
+            cur_data_map[sub_cur_path.resolve().as_posix()] = (
+                datetime.fromtimestamp(sub_cur_path.stat().st_mtime)
+                .astimezone(dateutil.tz.tzutc())
+                .timestamp()
+            )
+        else:
+            if wm:
+                wm.add_watch(sub_cur_path.as_posix(), mask, rec=True, auto_add=True)
+            cur_data_map.update(**path_time_recurse_func(sub_cur_path, wm=wm))
+    return cur_data_map
+
+
 wm = pyinotify.WatchManager()
 in_delete = getattr(pyinotify, "IN_DELETE")
 in_create = getattr(pyinotify, "IN_CREATE")
